@@ -9,7 +9,7 @@
 ##' @author guangchuang yu
 geom_phylopic <- function(mapping=NULL, data=NULL, inherit.aes=TRUE,
                        na.rm=FALSE, by="width", height = 512, ...) {
-    geom_image(mapping, data, inherit.aes=inherit.aes, na.rm=na.rm, ..., geom = 'phylopic', height = height)
+    geom_image(mapping, data, inherit.aes=inherit.aes, na.rm=na.rm, ..., height = height, .fun = phylopic)
 }
 
 
